// Licensed to Cloudera, Inc. under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  Cloudera, Inc. licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/*
---
description: Handles the resize linkers for the SplitView behavior.
provides: [JFrame.SplitViewLinkers]
requires: [/JFrame]
script: JFrame.SplitViewLinkers.js

...
*/

(function(){

var getWidget = function(link, container) {
	var widget = link.retrieve('_splitviewTarget');
	if (widget) return widget;
	var splitview = link.getParent('.splitview');
	if (!splitview) {
		var target = link.getData('splitview-target');
		if (target) splitview = container.getElement(target);
		if (!splitview) return;
	}
	widget = splitview.get('widget');
	link.store('_splitviewTarget', widget);
	widget.addEvent('fold', function(side, to, splitterhidden){
		var target = link.get('widget') || link;
		if (to > 0) target.addClass(side + '-open').addClass('splitview-open');
		else target.removeClass(side + '-open').removeClass('splitview-open');
	});
	return widget;
};
JFrame.addGlobalLinkers({

	'[data-splitview-resize]': function(e, link){
		if ($(e.target).get('tag') == 'a') e.preventDefault();
		var widget = getWidget(link, $(this));
		if (!widget) return;
		var resize = link.get('data', 'splitview-resize', true);
		if (!resize) return;
		var side;
		var sides = ['left', 'right', 'top', 'bottom'];
		for (key in resize) {
			if (sides.contains(key)) side = key;
		}
		widget.fold(side, resize[side], resize.hideSplitter, resize.noFx).chain(partialPostFold.bind(this, [resize, e, link]));
	},

	'[data-splitview-toggle]': function(e, link){
		if ($(e.target).get('tag') == 'a') e.preventDefault();
		var widget = getWidget(link, $(this));
		if (!widget) return;
		var resize = link.get('data', 'splitview-toggle', true);
		if (!resize) return;
		widget.toggle(resize.side, resize.hideSplitter, resize.noFx, resize.width).chain(partialPostFold.bind(this, [resize, e, link]));
	}

});

var partialPostFold = function(data, event, link){
	if (!$(document.body).hasChild(link)) return;
	if (data.partialRefresh) {
		if ($type(data.partialRefresh) == "string") link = new Element('a', { href: data.partialRefresh });
		this.invokeLinker('.jframe-fake_refresh', link, event);
	}
};

})();